This function generates a new series of affine resolvable Partially Balanced Incomplete Block Designs (PBIBDs) and its parameters (v, b1, b2, r, k1, k2), canonical efficiency factors, variance factor between associates and average variance factors.
Usage
PBIBD2(v, s, p, q)
Value
This function generates a PBIB design and its parameters, variance factors and efficiency factor.